View Source KafkaEx.Messages.ConsumerGroupDescription (kafka_ex v1.0.0-rc.1)

A detailed description of a single consumer group in the cluster.

Java equivalent: org.apache.kafka.clients.admin.ConsumerGroupDescription

Contains information about a consumer group's state, protocol, and members as returned by the DescribeGroups API.

Summary

Functions

Builds a ConsumerGroupDescription from a DescribeGroups API response.

Returns the group ID.

Returns the list of members in the group.

Returns whether the group is in the Stable state.

Returns the current state of the group.

Types

@type t() :: %KafkaEx.Messages.ConsumerGroupDescription{
  authorized_operations: integer() | nil,
  group_id: binary(),
  members: [KafkaEx.Messages.ConsumerGroupDescription.Member.t()],
  protocol: binary(),
  protocol_type: binary(),
  state: binary()
}

Functions

Link to this function

from_describe_group_response(describe_group)

@spec from_describe_group_response(map()) :: t()

Builds a ConsumerGroupDescription from a DescribeGroups API response.

Link to this function

group_id(consumer_group_description)

@spec group_id(t()) :: binary()

Returns the group ID.

Link to this function

members(consumer_group_description)

Returns the list of members in the group.

Link to this function

stable?(consumer_group_description)

@spec stable?(t()) :: boolean()

Returns whether the group is in the Stable state.

Link to this function

state(consumer_group_description)

@spec state(t()) :: binary()

Returns the current state of the group.