View Source KafkaEx.Messages.ConsumerGroupDescription.Member.MemberAssignment (kafka_ex v1.0.0-rc.1)

The current assignment for a consumer group member.

Java equivalent: org.apache.kafka.clients.consumer.ConsumerPartitionAssignor.Assignment

Contains the partition assignments and user data for a member. Will only be present if the group is stable.

Summary

Functions

Builds a MemberAssignment from a DescribeGroups API response.

Returns the partition assignments.

Returns the user data.

Returns the assignment version.

Types

@type response_partial() :: %{
  version: non_neg_integer(),
  partition_assignments: [
    KafkaEx.Messages.ConsumerGroupDescription.Member.MemberAssignment.PartitionAssignment.response_partial()
  ],
  user_data: binary()
}
@type t() :: %KafkaEx.Messages.ConsumerGroupDescription.Member.MemberAssignment{
  partition_assignments: [
    KafkaEx.Messages.ConsumerGroupDescription.Member.MemberAssignment.PartitionAssignment.t()
  ],
  user_data: binary(),
  version: non_neg_integer()
}

Functions

Link to this function

from_describe_group_response(response)

@spec from_describe_group_response(response_partial()) :: t()

Builds a MemberAssignment from a DescribeGroups API response.

Link to this function

partition_assignments(member_assignment)

Returns the partition assignments.

Link to this function

user_data(member_assignment)

@spec user_data(t()) :: binary()

Returns the user data.

Link to this function

version(member_assignment)

@spec version(t()) :: non_neg_integer()

Returns the assignment version.