View Source KafkaEx.Messages.ConsumerGroupDescription.Member.MemberAssignment.PartitionAssignment (kafka_ex v1.0.0-rc.1)

A topic-partition assignment for a consumer group member.

Contains the topic name and list of partition IDs assigned to a member. Will only be present if the group is stable.

Summary

Functions

Builds a PartitionAssignment from a DescribeGroups API response.

Returns the list of assigned partition IDs.

Returns the topic name.

Types

@type response_partial() :: %{topic: binary(), partitions: [non_neg_integer()]}
@type t() ::
  %KafkaEx.Messages.ConsumerGroupDescription.Member.MemberAssignment.PartitionAssignment{
    partitions: [non_neg_integer()],
    topic: binary()
  }

Functions

Link to this function

from_describe_group_response(response)

@spec from_describe_group_response(response_partial()) :: t()

Builds a PartitionAssignment from a DescribeGroups API response.

Link to this function

partitions(partition_assignment)

@spec partitions(t()) :: [non_neg_integer()]

Returns the list of assigned partition IDs.

Link to this function

topic(partition_assignment)

@spec topic(t()) :: binary()

Returns the topic name.