View Source KafkaEx.Messages.JoinGroup.Member (kafka_ex v1.0.0-rc.1)

Represents a member in the JoinGroup response.

The member_metadata field contains the serialized protocol metadata (as bytes) that was sent by this member in their join request. For consumer groups, this is typically a serialized GroupProtocolMetadata struct containing the list of topics the member is interested in.

Summary

Types

@type t() :: %KafkaEx.Messages.JoinGroup.Member{
  member_id: binary(),
  member_metadata: bitstring()
}