View Source KafkaEx.Protocol.Kayrock.ApiVersions.Request protocol (kafka_ex v1.0.0-rc.1)

This protocol is used to build ApiVersions requests.

For versions without a specific implementation, falls back to the Any implementation which returns the request struct unchanged (ApiVersions requests are parameterless for V0-V2, and V3+ has client software fields handled by explicit impls).

Summary

Types

t()

All the types that implement this protocol.

Types

@type t() :: term()

All the types that implement this protocol.

Functions

Link to this function

build_request(request, opts)

@spec build_request(t(), Keyword.t()) :: t()