View Source KafkaEx.Messages.ConsumerGroupDescription (kafka_ex v1.0.0-rc.1)
A detailed description of a single consumer group in the cluster.
Java equivalent: org.apache.kafka.clients.admin.ConsumerGroupDescription
Contains information about a consumer group's state, protocol, and members as returned by the DescribeGroups API.
Summary
Functions
Builds a ConsumerGroupDescription from a DescribeGroups API response.
Returns the group ID.
Returns the list of members in the group.
Returns whether the group is in the Stable state.
Returns the current state of the group.
Types
Functions
Builds a ConsumerGroupDescription from a DescribeGroups API response.
Returns the group ID.
@spec members(t()) :: [KafkaEx.Messages.ConsumerGroupDescription.Member.t()]
Returns the list of members in the group.
Returns whether the group is in the Stable state.
Returns the current state of the group.