View Source KafkaEx.Protocol.Kayrock.Metadata.Request protocol (kafka_ex v1.0.0-rc.1)
This protocol is used to build Metadata requests.
Each Kayrock.Metadata version (V0-V9) implements this protocol to transform request options into the appropriate Kayrock request struct.
The Any fallback is retained only for forward compatibility with
unknown future versions beyond what Kayrock currently supports.
Summary
Functions
Builds a Metadata request from options.
Types
@type t() :: term()
All the types that implement this protocol.